# Generated by Django 2.2.5 on 2019-09-16 17:59

from django.db import migrations
import isc_common.fields.description_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0064_auto_20190909_1409'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='message',
            field=isc_common.fields.description_field.DescriptionField(),
        ),
    ]
