# Generated by Django 2.2.7 on 2019-11-16 10:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0004_auto_20191017_1135'),
    ]

    operations = [
        migrations.CreateModel(
            name='Visitor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('session_key', models.CharField(max_length=40)),
                ('ip_address', models.CharField(max_length=20)),
                ('username', models.CharField(blank=True, max_length=255, null=True)),
                ('user_agent', models.CharField(max_length=255)),
                ('referrer', models.CharField(max_length=255)),
                ('url', models.CharField(max_length=255)),
                ('session_start', models.DateTimeField()),
                ('last_update', models.DateTimeField()),
            ],
            options={
                'verbose_name': 'Посетитель',
                'ordering': ('-last_update',),
                'unique_together': {('session_key', 'ip_address')},
            },
        ),
    ]
