# Generated by Django 2.2.3 on 2019-07-06 20:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0012_auto_20190706_1121'),
    ]

    operations = [
        migrations.CreateModel(
            name='Uuid_2_id',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(db_index=True)),
            ],
            options={
                'verbose_name': 'Таблица соответствия ID ',
            },
        ),
        migrations.AlterUniqueTogether(
            name='documents_param_1c',
            unique_together={('type', 'value', 'value_boolean', 'value_float', 'value_int', 'value_uuid')},
        ),
    ]
