# Generated by Django 3.0.3 on 2020-02-10 18:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0046_auto_20200210_1834'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='progresses',
            name='channel',
        ),
    ]
