# Generated by Django 2.2.4 on 2019-08-23 03:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0034_auto_20190823_0350'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Calendar_shifts_days',
        ),
    ]
