# Generated by Django 2.2.4 on 2019-08-23 09:29

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0036_auto_20190823_0357'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shift_day',
            name='calendar',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars'),
        ),
        migrations.CreateModel(
            name='Calendar_shifts_days',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('calendar', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars')),
                ('friday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='friday_rel', to='clndr.Shift_day')),
                ('monday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='monday_rel', to='clndr.Shift_day')),
                ('saturday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='saturday_rel', to='clndr.Shift_day')),
                ('shift', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='clndr.Shifts')),
                ('sunday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='sunday_rel', to='clndr.Shift_day')),
                ('thursday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='thursday_rel', to='clndr.Shift_day')),
                ('tuesday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='tuesday_rel', to='clndr.Shift_day')),
                ('wednesday', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='wednesday_rel', to='clndr.Shift_day')),
            ],
            options={
                'verbose_name': 'Рабочие смены по дням',
            },
        ),
    ]
