# Generated by Django 2.2.4 on 2019-08-21 01:08

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0006_auto_20190821_0100'),
    ]

    operations = [
        migrations.CreateModel(
            name='Shift_day',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('begintime', models.TimeField(db_index=True, verbose_name='Начало')),
                ('endtime', models.TimeField(db_index=True, verbose_name='Конец')),
                ('props', bitfield.models.BitField((('work', 'Рабочий'), ('holiday', 'Выходной')), db_index=True, default=None)),
                ('day', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='clndr.Day')),
            ],
            options={
                'verbose_name': 'День смены',
            },
        ),
    ]
