# Generated by Django 2.2.1 on 2019-05-15 19:59

from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.description_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0018_delete_messages_view'),
    ]

    operations = [
        migrations.CreateModel(
            name='Messages_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('checksum', isc_common.fields.code_field.CodeField(unique=True, verbose_name='Checksum MD5')),
                ('message', isc_common.fields.description_field.DescriptionField(verbose_name='Тело сообщения')),
                ('date_create', models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Дата записи')),
                ('isFolder', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'Сообщения',
                'db_table': 'tracker_messages_view',
                'managed': False,
            },
        ),
    ]
