# Generated by Django 3.0.3 on 2020-02-09 17:41

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0043_auto_20200209_1728'),
    ]

    operations = [
        migrations.AlterField(
            model_name='progresses',
            name='guid',
            field=models.UUIDField(default=uuid.UUID('1972b80d-d298-4671-ae8c-df8c67e2e6b4')),
        ),
    ]
