# Generated by Django 2.2.5 on 2019-09-13 10:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0016_auto_20190913_1055'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chat_user_user',
            name='common_id',
            field=models.PositiveIntegerField(),
        ),
    ]
