# Generated by Django 2.2.4 on 2019-08-25 10:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0062_auto_20190825_1019'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='calendar_shifts_days',
            options={'ordering': ['shiftorder'], 'verbose_name': 'Рабочие смены по дням'},
        ),
        migrations.RemoveField(
            model_name='shift_day',
            name='numdayinweek',
        ),
    ]
